@@ -132,36 +132,52 @@ def _stringify_query():
           any significant optimization will most likely require a major
           refactor of sql.Query class, which is a substantial part of ORM.
     """
+    # import django
+    # print django.VERSION
+
+
     import simplejson as json
     from datetime import datetime, date
     from django.db.models.expressions import ExpressionNode, F
     from django.db.models.fields import Field
+    from django.db.models.fields.related import ManyToOneRel
     from django.db.models.sql.where import Constraint, WhereNode, ExtraWhere
     from django.db.models.sql import Query
     from django.db.models.sql.aggregates import Aggregate
-    from django.db.models.sql.datastructures import RawValue, Date
+    from django.db.models.sql.datastructures import Date
     from django.db.models.sql.expressions import SQLEvaluator
 
     attrs = {}
+
+    # RawValue removed in Django 1.7
+    try:
+        from django.db.models.sql.datastructures import RawValue
+        attrs[RawValue] = ('value',)
+    except ImportError:
+        pass
+
     attrs[WhereNode] = attrs[ExpressionNode] \
-        = ('connector', 'negated', 'children', 'subtree_parents')
+        = ('connector', 'negated', 'children')
     attrs[SQLEvaluator] = ('expression',)
     attrs[ExtraWhere] = ('sqls', 'params')
     attrs[Aggregate] = ('source', 'is_summary', 'col', 'extra')
-    attrs[RawValue] = ('value',)
     attrs[Date] = ('col', 'lookup_type')
     attrs[F] = ('name',)
+    attrs[ManyToOneRel] = ('field',)
 
     q = Query(None)
     q_keys = q.__dict__.keys()
     q_ignored = ['join_map', 'dupe_avoidance', '_extra_select_cache', '_aggregate_select_cache',
                  'used_aliases']
     attrs[Query] = tuple(sorted( set(q_keys) - set(q_ignored) ))
+    # print 'QQQ>', attrs[Query]
 
     for k, v in attrs.items():
         attrs[k] = map(intern, v)
 
     def encode_object(obj):
+        # if not isinstance(obj, type):
+        #     print '>>>>>', obj, getattr(obj, '__dict__', None)
         if isinstance(obj, set):
             return sorted(obj)
         elif isinstance(obj, type):
@@ -184,7 +200,7 @@ def _stringify_query():
             # for custom subclasses of Query
             return (obj.__class__, [getattr(obj, attr) for attr in attrs[Query]])
         else:
-            raise TypeError("Can't encode %s" % repr(obj))
+            raise TypeError("Can't stringify %s" % repr(obj))
 
     def stringify_query(query):
         # HACK: Catch TypeError and reraise it as ValueError
@@ -236,6 +252,9 @@ class QuerySetMixin(object):
         md5.update(str(self.__class__))
         md5.update(stamp_fields(self.model)) # Protect from field list changes in model
         md5.update(stringify_query(self.query))
+        # If query results differ depending on database
+        if not self._cacheprofile['db_agnostic']:
+            md5.update(self.db)
         if extra:
             md5.update(str(extra))
         # 'flat' attribute changes results formatting for ValuesQuerySet
